@@ -1,3 +1,4 @@
+import sys
 import os
 from pathlib import Path
 
@@ -5,9 +6,12 @@ package_path = os.path.split(
     os.path.realpath(__file__)
 )[0]
 
+sys.path.append(package_path)
+
 files = os.listdir(package_path)
 
 for file in files:
+
     module = Path(file).stem
 
     if not module.endswith('tools'):  # specific to this package
