@@ -1,4 +1,10 @@
 # -*- coding: utf-8 -*-
+"""
+=================
+interactive_tools
+=================
+"""
+
 import sys
 from .print_tools import print_
 
@@ -6,8 +12,9 @@ from .print_tools import print_
 ## Wait for a key press on the console and return it
 def wait_for_key(
     text: str = 'continue: press any button',
-    color: str = 'black',
-    list_bullet: (bool, str) = False
+    color: str = None,
+    list_bullet: (bool, str) = False,
+    indent: int = None
 ) -> 'None or str':
     ''' Wait for a key press on the console and return it.'''
 
@@ -15,7 +22,8 @@ def wait_for_key(
         print_(
             text,
             color=color,
-            list_bullet=list_bullet
+            list_bullet=list_bullet,
+            indent=indent
         )
 
     result = None
