@@ -1,7 +1,7 @@
 # coding=utf-8
 """
 run the test from the sr/invesytoolbox directory:
-python ../tests/test_data.py
+python ../tests/test_print.py
 """
 
 import sys
@@ -28,7 +28,8 @@ class TestSystem(unittest.TestCase):
             'mit Ümläuten und Zeilenenden', '\n',
             'bla bla bla',
             color={2: 'red'},
-            sep='#'
+            sep='#',
+            list_bullet='+'
         )
 
 
