@@ -1,7 +1,7 @@
 # coding=utf-8
 """
 run the test from the sr/invesytoolbox directory:
-python ../tests/test_data.py
+python ../tests/test_system.py
 """
 
 import sys
